my $app = Zim::GUI->current();

eval 'use Zim::GUI::TrayIcon';
if ($@) {
	$app->error_dialog(
		"Failed to load TrayIcon plugin.\n".
		"You either need gtk+ >= 2.10 or you".
		"need to have Gtk2::TrayIcon installed.", $@);
	$app->unplug('TrayIcon');
	return 1;
}

my $trayicon = Zim::GUI::TrayIcon->new(app => $app);
$app->add_object(TrayIcon => $trayicon);

1;
